summaryrefslogtreecommitdiffstats
path: root/krec/krecglobal.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:43:15 +0000
commite654398e46e37abf457b2b1122ab898d2c51c49f (patch)
treed39ee6440f3c3663c3ead84a2d4cc2d034667e96 /krec/krecglobal.h
parente4f29b18e19394b9352f52a6c0d0d0e3932cf511 (diff)
downloadtdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.tar.gz
tdemultimedia-e654398e46e37abf457b2b1122ab898d2c51c49f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1157644 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'krec/krecglobal.h')
-rw-r--r--krec/krecglobal.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/krec/krecglobal.h b/krec/krecglobal.h
index 6955eb14..f29a786d 100644
--- a/krec/krecglobal.h
+++ b/krec/krecglobal.h
@@ -14,10 +14,10 @@
#ifndef KREC_GLOBAL_H
#define KREC_GLOBAL_H
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qdict.h>
+#include <tqobject.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
+#include <tqdict.h>
class KConfig;
class QWidget;
@@ -25,10 +25,10 @@ class KStatusBar;
class KRecExportItem;
-class KRecGlobal : public QObject {
+class KRecGlobal : public TQObject {
Q_OBJECT
private:
- KRecGlobal( QObject* =0, const char* =0 );
+ KRecGlobal( TQObject* =0, const char* =0 );
~KRecGlobal();
public:
@@ -41,13 +41,13 @@ public:
/**
* Sets the MainWidget.
*/
- void setMainWidget( QWidget* );
+ void setMainWidget( TQWidget* );
/**
* Returns a pointer to the mainwidget.
* Usefull to display Messageboxes, etc correctly without beeing a
* QWidget or knowing about a parent QWidget.
*/
- QWidget* mainWidget();
+ TQWidget* mainWidget();
/// @return kapp->config()
static KConfig* kconfig();
@@ -58,7 +58,7 @@ public:
* Puts a message into the statusbar.
* Usefull for showing messages without knowing about the Statusbar.
*/
- void message( const QString & );
+ void message( const TQString & );
/// Registers a KRecExportItem
static bool registerExport( KRecExportItem* );
@@ -66,13 +66,13 @@ public:
* Returns a new KRecExportItem for the specified exportFormat.
* If now Item can be found the return value is 0.
*/
- KRecExportItem* getExportItem( const QString &exportFormat );
+ KRecExportItem* getExportItem( const TQString &exportFormat );
///
- KRecExportItem* getExportItemForEnding( const QString & );
+ KRecExportItem* getExportItemForEnding( const TQString & );
/// Returns a list of exportFormats.
- QStringList exportFormats() const;
+ TQStringList exportFormats() const;
/// Returns a list of fileendings.
- QString exportFormatEndings() const;
+ TQString exportFormatEndings() const;
/**
* Gets/Sets the actual mode for formating time values.
@@ -85,10 +85,10 @@ public:
int frameBase();
void setFrameBase( int );
private:
- QWidget *_qwidget;
+ TQWidget *_qwidget;
KStatusBar *_statusbar;
- QDict <KRecExportItem> *_exports;
- QStringList _exportformats;
+ TQDict <KRecExportItem> *_exports;
+ TQStringList _exportformats;
int _timeformatcache, _framebasecache;
};
@@ -41,13 +41,13 @@ public:
* Returns a pointer to the mainwidget.
* Usefull to display Messageboxes, etc correctly without beeing a
- * QWidget or knowing about a parent QWidget.
+ * TQWidget or knowing about a parent TQWidget.
*/